@@ -15,8 +15,8 @@
 
 import abc
 
-from neutron.common import rpc as n_rpc
 from neutron.db import agents_db
+from neutron_lib import rpc as n_rpc
 
 from networking_l2gw._i18n import _
 from networking_l2gw.db.l2gateway import l2gateway_db as l2_gw_db
@@ -34,12 +34,12 @@ from neutron.plugins.ml2 import managers
 
 from neutron_lib.api.definitions import portbindings
 from neutron_lib import constants as n_const
+from neutron_lib.db import api as db_api
 from neutron_lib import exceptions
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
 from oslo_utils import importutils
-import six
 
 LOG = logging.getLogger(__name__)
 
@@ -48,8 +48,7 @@ L2GW_CALLBACK = ("networking_l2gw.services.l2gateway.ovsdb."
                  "data.L2GatewayOVSDBCallbacks")
 
 
-@six.add_metaclass(abc.ABCMeta)
-class L2gwRpcDriver(service_drivers.L2gwDriver):
+class L2gwRpcDriver(service_drivers.L2gwDriver, metaclass=abc.ABCMeta):
     """L2gw RPC Service Driver class."""
 
     def __init__(self, service_plugin, validator=None):
@@ -350,7 +349,9 @@ class L2gwRpcDriver(service_drivers.L2gwDriver):
     def _validate_gateway_for_update(self, context, gw):
         LOG.debug("L2gwRpcDriver._validate_gateway_for_update gw=%s",
                   gw)
-        devices = gw.get('l2_gateway').get('devices')
+        # Note(lajoskatona): If the update is updating other keys than
+        # devices, just return, as the tricky part is updating devices.
+        devices = gw['l2_gateway'].get('devices', [])
 
         for device in devices:
             interfaces = device.get('interfaces')
@@ -751,7 +752,7 @@ class L2gwRpcDriver(service_drivers.L2gwDriver):
     def delete_l2_gateway(self, context, id):
         """delete the l2 gateway by id."""
         self.l2gateway_db._admin_check(context, 'DELETE')
-        with context.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(context):
             gw_db = self.l2gateway_db._get_l2_gateway(context, id)
             if gw_db is None:
                 raise l2gw_exc.L2GatewayNotFound(gateway_id=id)
