@@ -44,7 +44,7 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
     def _create_logical_switch(self, record_dict, name=None):
         if name:
             record_dict['name'] = name
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = models.LogicalSwitches(
                 uuid=record_dict['uuid'],
                 name=record_dict['name'],
@@ -53,12 +53,16 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
             self.ctx.session.add(entry)
             return entry
 
+    def _assert_model_equals(self, entry, result):
+        for field, res in result.items():
+            self.assertEqual(str(entry[field]), str(res))
+
     def test_get_logical_switch(self):
         record_dict = self._get_logical_switch_dict()
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = self._create_logical_switch(record_dict)
         result = lib.get_logical_switch(self.ctx, record_dict)
-        self.assertEqual(entry, result)
+        self._assert_model_equals(entry, result)
 
     def test_get_logical_switch_return_none(self):
         record_dict = {'uuid': 'foo_uuid', 'ovsdb_identifier': 'foo_ovsdb_id'}
@@ -88,7 +92,7 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
     def _create_physical_locator(self, record_dict, dst_ip=None):
         if dst_ip:
             record_dict['dst_ip'] = dst_ip
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = models.PhysicalLocators(
                 uuid=record_dict['uuid'],
                 dst_ip=record_dict['dst_ip'],
@@ -98,10 +102,10 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
 
     def test_get_physical_locator(self):
         record_dict = self._get_physical_locator_dict()
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = self._create_physical_locator(record_dict)
         result = lib.get_physical_locator(self.ctx, record_dict)
-        self.assertEqual(entry, result)
+        self._assert_model_equals(entry, result)
 
     def test_add_physical_locator(self):
         record_dict = self._get_physical_locator_dict()
@@ -127,7 +131,7 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
     def _create_physical_switch(self, record_dict, name=None):
         if name:
             record_dict['name'] = name
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = models.PhysicalSwitches(
                 uuid=record_dict['uuid'],
                 name=record_dict['name'],
@@ -138,10 +142,10 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
 
     def test_get_physical_switch(self):
         record_dict = self._get_physical_switch_dict()
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = self._create_physical_switch(record_dict)
         result = lib.get_physical_switch(self.ctx, record_dict)
-        self.assertEqual(entry, result)
+        self._assert_model_equals(entry, result)
 
     def test_add_physical_switch(self):
         record_dict = self._get_physical_switch_dict()
@@ -181,7 +185,7 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
         if name and physical_switch_id:
             record_dict['name'] = name
             record_dict['physical_switch_id'] = physical_switch_id
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = models.PhysicalPorts(
                 uuid=record_dict['uuid'],
                 name=record_dict['name'],
@@ -192,10 +196,10 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
 
     def test_get_physical_port(self):
         record_dict = self._get_physical_port_dict()
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = self._create_physical_port(record_dict)
         result = lib.get_physical_port(self.ctx, record_dict)
-        self.assertEqual(entry, result)
+        self._assert_model_equals(entry, result)
 
     def test_add_physical_port(self):
         record_dict = self._get_physical_port_dict()
@@ -232,7 +236,7 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
         return record_dict
 
     def _create_ucast_mac_local(self, record_dict):
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = models.UcastMacsLocals(
                 uuid=record_dict['uuid'],
                 mac=record_dict['mac'],
@@ -245,10 +249,10 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
 
     def test_get_ucast_mac_local(self):
         record_dict = self._get_ucast_mac_local_dict()
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = self._create_ucast_mac_local(record_dict)
         result = lib.get_ucast_mac_local(self.ctx, record_dict)
-        self.assertEqual(entry, result)
+        self._assert_model_equals(entry, result)
 
     def test_add_ucast_mac_local(self):
         record_dict = self._get_ucast_mac_local_dict()
@@ -354,7 +358,7 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
     def _create_vlan_binding(self, record_dict, port_uuid=None):
         if port_uuid:
             record_dict['port_uuid'] = port_uuid
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = models.VlanBindings(
                 port_uuid=record_dict['port_uuid'],
                 vlan=record_dict['vlan'],
@@ -365,10 +369,10 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
 
     def test_get_vlan_binding(self):
         record_dict = self._get_vlan_binding_dict()
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = self._create_vlan_binding(record_dict)
         result = lib.get_vlan_binding(self.ctx, record_dict)
-        self.assertEqual(entry, result)
+        self._assert_model_equals(entry, result)
 
     def test_add_vlan_binding(self):
         record_dict = self._get_vlan_binding_dict()
@@ -401,12 +405,12 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
 
     def test_get_logical_switch_by_name(self):
         record_dict = self._get_logical_switch_dict()
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = self._create_logical_switch(record_dict,
                                                 'logical_switch2')
         record_dict['logical_switch_name'] = 'logical_switch2'
         result = lib.get_logical_switch_by_name(self.ctx, record_dict)
-        self.assertEqual(entry, result)
+        self._assert_model_equals(entry, result)
 
     def test_get_all_logical_switch_by_name(self):
         record_dict1 = self._get_logical_switch_dict()
@@ -419,21 +423,21 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
 
     def test_get_physical_locator_by_dst_ip(self):
         record_dict = self._get_physical_locator_dict()
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = self._create_physical_locator(record_dict, '20.0.0.1')
         record_dict['dst_ip'] = '20.0.0.1'
         record_dict.pop('uuid')
         result = lib.get_physical_locator_by_dst_ip(self.ctx, record_dict)
-        self.assertEqual(entry, result)
+        self._assert_model_equals(entry, result)
 
     def test_get_physical_switch_by_name(self):
         record_dict = self._get_physical_switch_dict()
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = self._create_physical_switch(record_dict,
                                                  'physical_switch2')
         result = lib.get_physical_switch_by_name(self.ctx,
                                                  'physical_switch2')
-        self.assertEqual(entry, result)
+        self._assert_model_equals(entry, result)
 
     def test_get_all_vlan_bindings_by_physical_port(self):
         record_dict1 = {'port_uuid': 'ps123',
@@ -471,7 +475,7 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
 
     def test_get_physical_port_by_name_and_ps(self):
         record_dict = self._get_physical_port_dict()
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = self._create_physical_port(record_dict,
                                                'port1',
                                                'ps123')
@@ -479,7 +483,7 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
         record_dict['physical_switch_id'] = 'ps123'
         result = lib.get_physical_port_by_name_and_ps(self.ctx,
                                                       record_dict)
-        self.assertEqual(entry, result)
+        self._assert_model_equals(entry, result)
 
     def _get_pending_mac_dict(self, timestamp):
         record_dict = {'uuid': _uuid(),
@@ -494,7 +498,7 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
         return record_dict
 
     def _create_pending_mac(self, record_dict):
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = models.PendingUcastMacsRemote(
                 uuid=record_dict['uuid'],
                 mac=record_dict['mac'],
@@ -518,12 +522,12 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
     def test_get_pending_ucast_mac_remote(self):
         timestamp = timeutils.utcnow()
         record_dict = self._get_pending_mac_dict(timestamp)
-        with self.ctx.session.begin(subtransactions=True):
+        with db_api.CONTEXT_WRITER.using(self.ctx):
             entry = self._create_pending_mac(record_dict)
         result = lib.get_pending_ucast_mac_remote(
             self.ctx, record_dict['ovsdb_identifier'],
             record_dict['mac'], record_dict['logical_switch_uuid'])
-        self.assertEqual(entry, result)
+        self._assert_model_equals(entry, result)
 
     def test_get_all_pending_remote_macs_in_asc_order(self):
         timestamp1 = timeutils.utcnow()
